@@ -40,6 +40,12 @@ class SelfServiceUser:
     def set_password(self, token, password):
         return self.request('passwordreset/set_password', token=token, password=password).result
 
+    def auth(self):
+        self._client.umc_auth(self.username, self.password)
+
+    def command(self, uri, **kwargs):
+        return self._client.umc_command(uri, kwargs)
+
 
 @contextlib.contextmanager
 def self_service_user(email=None, **kwargs):
@@ -49,9 +55,10 @@ def self_service_user(email=None, **kwargs):
         if email:
             kwargs['PasswordRecoveryEmail'] = email
         password = kwargs.setdefault('password', uts.random_string())
+        language = kwargs.pop('language', None)
         dn, username = udm.create_user(**kwargs)
         utils.verify_ldap_object(dn)
-        yield SelfServiceUser(username, password)
+        yield SelfServiceUser(username, password, language=language)
 
 
 # copy pasted to 86_selenium/test_self_service.py
